# time-jit.R

library(jit)

GCTORTURE.FLAG <- 0
TRACE.FLAG <- 0
QUICK.FLAG <- FALSE   # FALSE for full test, TRUE for quick test
NREPEATS <- 5         # for calculating time stddev
if (QUICK.FLAG == 1)
    NREPEATS <- 1

print(R.version.string)

JIT.FLAG <- 1
source("time-jit-lib.R")

if (is.ra) {
    JIT.FLAG <- 2
    source("time-jit-lib.R")
}
